@@ -18,7 +18,7 @@ use Config::IniFiles;
 
 use vars qw($VERSION);
 
-$VERSION = '0.22';
+$VERSION = '0.24';
 
 use constant DATABASE_FILE => 'cpansmoke.dat';
 use constant CONFIG_FILE   => 'cpansmoke.ini';
@@ -99,6 +99,9 @@ my %throw_away;
 		  $report =~ s/\[MSG\].*may need to build a \'CPANPLUS::Dist::YACSmoke\' package for it as well.*?\n//sg;
 		  $report .=
 			"\nThis report was machine-generated by CPANPLUS::Dist::YACSmoke $VERSION.\n";
+		  if ( $ENV{PERL5_MINIYACSMOKER} ) {
+			$report .= "Powered by miniyacsmoker version " . $ENV{PERL5_MINIYACSMOKER} . "\n";
+		  }
 		  $report .= _gen_report();
 		  return $report;
         },
